import { BaseVertexAPI } from '../base';
import { OptionalSignatureParams } from '../types';
import { BurnLpParams, CancelAndPlaceOrderParams, CancelOrdersParams, CancelProductOrdersParams, CancelTriggerOrdersParams, CancelTriggerProductOrdersParams, MintLpParams, PlaceIsolatedOrderParams, PlaceOrderParams, PlaceTriggerOrderParams } from './types';
export declare class MarketExecuteAPI extends BaseVertexAPI {
    /**
     * Mint LP tokens through engine
     * @param params
     */
    mintLp(params: MintLpParams): Promise<import("@vertex-protocol/engine-client").EngineServerExecuteSuccessResult<"mint_lp">>;
    /**
     * Burn LP tokens through engine
     * @param params
     */
    burnLp(params: BurnLpParams): Promise<import("@vertex-protocol/engine-client").EngineServerExecuteSuccessResult<"burn_lp">>;
    /**
     * Places an order through the engine
     * @param params
     */
    placeOrder(params: PlaceOrderParams): Promise<import("@vertex-protocol/engine-client").EnginePlaceOrderResult>;
    /**
     * Places an isolated order through the engine
     * @param params
     */
    placeIsolatedOrder(params: PlaceIsolatedOrderParams): Promise<import("@vertex-protocol/engine-client").EnginePlaceIsolatedOrderResult>;
    /**
     * Cancels orders through the engine
     * @param params
     */
    cancelOrders(params: CancelOrdersParams): Promise<import("@vertex-protocol/engine-client").EngineServerExecuteSuccessResult<"cancel_orders">>;
    /**
     * Cancels orders through the engine and places a new one
     * @param params
     */
    cancelAndPlace(params: CancelAndPlaceOrderParams): Promise<import("@vertex-protocol/engine-client").EngineServerExecuteSuccessResult<"cancel_and_place">>;
    /**
     * Cancels all orders for provided products through the engine.
     * @param params
     */
    cancelProductOrders(params: CancelProductOrdersParams): Promise<import("@vertex-protocol/engine-client").EngineServerExecuteSuccessResult<"cancel_product_orders">>;
    /**
     * Places a trigger order through the trigger service
     * @param params
     */
    placeTriggerOrder(params: PlaceTriggerOrderParams): Promise<import("@vertex-protocol/trigger-client").TriggerServerExecuteSuccessResult<"place_order">>;
    /**
     * Cancels all trigger orders for provided digests through the trigger service.
     * @param params
     */
    cancelTriggerOrders(params: CancelTriggerOrdersParams): Promise<import("@vertex-protocol/trigger-client").TriggerServerExecuteSuccessResult<"cancel_orders">>;
    /**
     * Cancels all trigger orders for provided products through the trigger service.
     * @param params
     */
    cancelTriggerProductOrders(params: CancelTriggerProductOrdersParams): Promise<import("@vertex-protocol/trigger-client").TriggerServerExecuteSuccessResult<"cancel_product_orders">>;
    protected getOrderbookVerifyingAddressIfNeeded(params: OptionalSignatureParams<{
        productId: number;
    }>): Promise<string>;
}
//# sourceMappingURL=MarketExecuteAPI.d.ts.map