import { GetAllMarketsResponse } from '@vertex-protocol/contracts';
import { GetEngineMarketLiquidityParams, GetEngineMarketPriceParams, GetEngineMarketPricesParams, GetEngineMaxMintLpAmountParams, GetEngineMaxOrderSizeParams, GetEngineSubaccountOrdersParams, GetEngineSubaccountProductOrdersParams, ValidateEngineOrderParams } from '@vertex-protocol/engine-client';
import { GetIndexerCandlesticksParams, GetIndexerEdgeCandlesticksParams, GetIndexerEdgeMarketSnapshotsParams, GetIndexerFundingRateParams, GetIndexerMarketSnapshotsParams, GetIndexerMultiProductFundingRatesParams, GetIndexerMultiProductSnapshotsParams, GetIndexerOrdersParams, GetIndexerOrdersResponse, GetIndexerProductSnapshotsParams } from '@vertex-protocol/indexer-client';
import { BaseVertexAPI } from '../base';
import { GetTriggerOrdersParams } from './types';
export declare class MarketQueryAPI extends BaseVertexAPI {
    /**
     * Retrieves all market states from the on-chain contracts
     */
    getAllMarkets(): Promise<GetAllMarketsResponse>;
    /**
     * Retrieves all market states from the offchain engine
     */
    getAllEngineMarkets(): Promise<GetAllMarketsResponse>;
    /**
     * Get all edge engine markets
     */
    getEdgeAllEngineMarkets(): Promise<Record<number, GetAllMarketsResponse>>;
    /**
     * Retrieves all spread health groups
     */
    getHealthGroups(): Promise<import("@vertex-protocol/engine-client").GetEngineHealthGroupsResponse>;
    /**
     * Queries engine to determine if the order can be submitted within health requirements
     */
    validateOrderParams(params: ValidateEngineOrderParams): Promise<import("@vertex-protocol/engine-client").ValidateEngineOrderResponse>;
    /**
     * Queries the offchain engine to retrieve status of any open orders for the given subaccount
     * @param params
     */
    getOpenSubaccountOrders(params: GetEngineSubaccountOrdersParams): Promise<import("@vertex-protocol/engine-client").EngineSubaccountOrders>;
    /**
     * Queries the offchain engine to retrieve status of any open orders for the given subaccount for multiple products
     * @param params
     */
    getOpenSubaccountMultiProductOrders(params: GetEngineSubaccountProductOrdersParams): Promise<import("@vertex-protocol/engine-client").GetEngineSubaccountProductOrdersResponse>;
    /**
     * Queries the offchain trigger service to list trigger orders. Requires a signature
     * @param params
     */
    getTriggerOrders(params: GetTriggerOrdersParams): Promise<import("@vertex-protocol/trigger-client").TriggerListOrdersResponse>;
    /**
     * Queries indexer to fetch historical orders
     *
     * @param params
     */
    getHistoricalOrders(params: GetIndexerOrdersParams): Promise<GetIndexerOrdersResponse>;
    /**
     * Queries engine to determine maximum order size
     * @param params
     */
    getMaxOrderSize(params: GetEngineMaxOrderSizeParams): Promise<import("bignumber.js").BigNumber>;
    /**
     * Queries engine to determine maximum base & quote amounts for minting LPs
     * @param params
     */
    getMaxMintLpAmount(params: GetEngineMaxMintLpAmountParams): Promise<import("@vertex-protocol/engine-client").GetEngineMaxMintLpAmountResponse>;
    /**
     * Retrieves liquidity per price tick from the engine. The engine will skip price levels that have no liquidity,
     * so it is not guaranteed that the bids/asks are evenly spaced
     */
    getMarketLiquidity(params: GetEngineMarketLiquidityParams): Promise<import("@vertex-protocol/engine-client").GetEngineMarketLiquidityResponse>;
    /**
     * Historical candlesticks from the indexer, use getLatestMarketPrice for the latest orderbook prices
     *
     * @param params
     */
    getCandlesticks(params: GetIndexerCandlesticksParams): Promise<import("@vertex-protocol/indexer-client").GetIndexerCandlesticksResponse>;
    /**
     * Historical candlesticks from Edge, use getLatestMarketPrice for the latest orderbook prices
     *
     * @param params
     */
    getEdgeCandlesticks(params: GetIndexerEdgeCandlesticksParams): Promise<import("@vertex-protocol/indexer-client").GetIndexerCandlesticksResponse>;
    /**
     * Retrieves the latest off-chain orderbook price from the engine
     *
     * @param params
     */
    getLatestMarketPrice(params: GetEngineMarketPriceParams): Promise<import("@vertex-protocol/engine-client").EngineMarketPrice>;
    /**
     * Retrieves the latest off-chain orderbook price from the engine for multiple markets
     *
     * @param params
     */
    getLatestMarketPrices(params: GetEngineMarketPricesParams): Promise<import("@vertex-protocol/engine-client").GetEngineMarketPricesResponse>;
    /**
     * Retrieves the latest funding rate for a perp product
     *
     * @param params
     */
    getFundingRate(params: GetIndexerFundingRateParams): Promise<import("@vertex-protocol/indexer-client").IndexerFundingRate>;
    /**
     * Retrieves the latest funding rate for multiple perp products
     *
     * @param params
     */
    getMultiProductFundingRates(params: GetIndexerMultiProductFundingRatesParams): Promise<import("@vertex-protocol/indexer-client").GetIndexerMultiProductFundingRatesResponse>;
    /**
     * Retrieves the historical snapshots for a product from the indexer
     *
     * @param params
     */
    getProductSnapshots(params: GetIndexerProductSnapshotsParams): Promise<import("@vertex-protocol/indexer-client").GetIndexerProductSnapshotsResponse>;
    /**
     * Retrieves the historical snapshots for a market from the indexer
     *
     * @param params
     */
    getMarketSnapshots(params: GetIndexerMarketSnapshotsParams): Promise<import("@vertex-protocol/indexer-client").GetIndexerMarketSnapshotsResponse>;
    /**
     * Retrieves the historical snapshots for a market from Edge
     *
     * @param params
     */
    getEdgeMarketSnapshots(params: GetIndexerEdgeMarketSnapshotsParams): Promise<import("@vertex-protocol/indexer-client").GetIndexerEdgeMarketSnapshotResponse>;
    /**
     * Retrieves the historical snapshots for multiple products from the indexer
     *
     * @param params
     */
    getMultiProductSnapshots(params: GetIndexerMultiProductSnapshotsParams): Promise<import("@vertex-protocol/indexer-client").GetIndexerMultiProductSnapshotsResponse>;
}
//# sourceMappingURL=MarketQueryAPI.d.ts.map