import { BaseRewardsAPI } from './BaseRewardsAPI';
import { ClaimLiquidTokensParams, ClaimLiquidTokensSatelliteParams, SatelliteCcipParams, StakeSatelliteParams, VrtxTokenAmountParams } from './types';
export declare class RewardsExecuteAPI extends BaseRewardsAPI {
    /**
     *
     *  LBA/Airdrop
     *
     */
    /**
     * Withdraw LP liquidity tokens from the LBA pool after the AMM has been created
     */
    withdrawLbaLiquidity(params: VrtxTokenAmountParams): Promise<`0x${string}`>;
    /**
     * Claim earned VRTX tokens
     */
    claimLiquidTokens(params: ClaimLiquidTokensParams): Promise<`0x${string}`>;
    /**
     * Claim earned VRTX tokens and stake them
     */
    claimAndStakeLiquidTokens(params: ClaimLiquidTokensParams): Promise<`0x${string}`>;
    /**
     * Claim earned VRTX tokens on non-canonical chains
     */
    claimLiquidTokensSatellite(params: ClaimLiquidTokensSatelliteParams): Promise<`0x${string}`>;
    /**
     * Claim trading rewards and stake the claimed VRTX on non-canonical chains
     */
    claimAndStakeLiquidTokensSatellite(params: ClaimLiquidTokensSatelliteParams): Promise<`0x${string}`>;
    /**
     * Claim VRTX rewards associated with keeping liquidity in the LBA
     */
    claimLbaRewards(): Promise<`0x${string}`>;
    /**
     *
     *  V1 Staking
     *
     */
    /**
     * Claim unlocked tokens that were previously unstaked
     */
    withdrawUnstakedV1Tokens(): Promise<`0x${string}`>;
    /**
     * Claim staking rewards (in USDC)
     */
    claimV1StakingRewards(): Promise<`0x${string}`>;
    /**
     * Migrate VRTX tokens from the old staking contract to the new staking contract
     */
    migrateToStakingV2(): Promise<`0x${string}`>;
    /**
     * Unstake VRTX tokens, unstaked tokens that are unlocked will need to be withdrawn
     */
    unstakeV1(params: VrtxTokenAmountParams): Promise<`0x${string}`>;
    /**
     *
     *  V2 Staking
     *
     */
    /**
     * Stake V2 VRTX tokens
     */
    stake(params: VrtxTokenAmountParams): Promise<`0x${string}`>;
    /**
     * Unstake V2 VRTX tokens, unstake tokens instantly with a penalty that is redistributed
     */
    unstake(): Promise<`0x${string}`>;
    /**
     * Unstake V2 VRTX tokens, unstaked tokens that are unlocked will need to be claimed
     * after 21 day locking period
     */
    unstakeSlow(): Promise<`0x${string}`>;
    /**
     * Claim unlocked V2 tokens that were previously unstaked
     */
    withdrawUnstakedTokens(): Promise<`0x${string}`>;
    /**
     *
     *  Staking Satellite
     *
     */
    /**
     * Stake V2 VRTX tokens on non-canonical chains
     */
    stakeSatellite(params: StakeSatelliteParams): Promise<`0x${string}`>;
    /**
     * Unstake V2 VRTX tokens on non-canonical chains, unstake tokens instantly with a penalty that is redistributed
     * to the staking contract
     */
    unstakeSatellite(params: SatelliteCcipParams): Promise<`0x${string}`>;
    /**
     * Unstake V2 VRTX tokens on non-canonical chains, unstaked tokens that are unlocked will need to be claimed
     * after 21 day locking period
     */
    unstakeSlowSatellite(params: SatelliteCcipParams): Promise<`0x${string}`>;
    /**
     * Claim unlocked V2 tokens that were previously unstaked on non-canonical chains
     */
    withdrawUnstakedTokensSatellite(params: SatelliteCcipParams): Promise<`0x${string}`>;
    /**
     *
     *  Foundation Rewards
     *
     */
    /**
     * Claims all available foundation rewards. Foundation rewards are tokens associated with the chain. For example, ARB on Arbitrum.
     * Typically, foundations for these chains will issue rewards for us to give to users.
     */
    claimFoundationRewards(): Promise<`0x${string}`>;
}
//# sourceMappingURL=RewardsExecuteAPI.d.ts.map