import { getValidatedAddress, toBigDecimal, } from '@vertex-protocol/utils';
import { BaseSpotAPI } from './BaseSpotAPI';
export class SpotQueryAPI extends BaseSpotAPI {
    /**
     * Gets the estimated max withdrawable amount for a product
     * @param params
     */
    async getMaxWithdrawable(params) {
        return this.context.engineClient.getMaxWithdrawable(params);
    }
    /**
     * Queries engine to determine maximum quote amount for minting VLP.
     *
     * @param params
     */
    async getMaxMintVlpAmount(params) {
        return this.context.engineClient.getMaxMintVlpAmount(params);
    }
    /**
     * Helper to get current token balance in the user's wallet (i.e. not in a Vertex subaccount)
     */
    async getTokenWalletBalance({ address, ...rest }) {
        const token = await this.getTokenContractForProduct(rest);
        return token.read.balanceOf([getValidatedAddress(address)]);
    }
    /**
     * Helper to get current token allowance
     */
    async getTokenAllowance({ address, ...rest }) {
        const token = await this.getTokenContractForProduct(rest);
        return toBigDecimal(await token.read.allowance([
            getValidatedAddress(address),
            this.getEndpointAddress(),
        ]));
    }
}
//# sourceMappingURL=SpotQueryAPI.js.map