import { GetSubaccountSummaryParams } from '@vertex-protocol/contracts';
import { GetEngineEstimatedSubaccountSummaryParams, GetEngineIsolatedPositionsParams, GetEngineSubaccountFeeRatesParams, GetEngineSubaccountSummaryParams } from '@vertex-protocol/engine-client';
import { GetIndexerLinkedSignerParams, GetIndexerReferralCodeParams } from '@vertex-protocol/indexer-client';
import { BaseVertexAPI } from '../base';
export declare class SubaccountQueryAPI extends BaseVertexAPI {
    /**
     * Returns a comprehensive summary for a subaaccount, including its balances and health
     *
     * @see {@link getSubaccountSummary:CONTRACTS | getSubaccountSummary}
     */
    getSubaccountSummary(params: GetSubaccountSummaryParams): Promise<import("@vertex-protocol/contracts").SubaccountSummaryResponse>;
    /**
     * Gets the subaccount state according to the offchain engine
     * @param params
     */
    getEngineSubaccountSummary(params: GetEngineSubaccountSummaryParams): Promise<import("@vertex-protocol/contracts").SubaccountSummaryResponse>;
    /**
     * Gets the estimated subaccount state from offchain engine after a series of proposed txs
     * @param params
     */
    getEngineEstimatedSubaccountSummary(params: GetEngineEstimatedSubaccountSummaryParams): Promise<import("@vertex-protocol/contracts").SubaccountSummaryResponse>;
    /**
     * Gets the isolated positions for a subaccount
     * @param params
     */
    getIsolatedPositions(params: GetEngineIsolatedPositionsParams): Promise<import("@vertex-protocol/engine-client").GetEngineIsolatedPositionsResponse>;
    /**
     * Queries engine to get subaccount fee rates
     * @param params
     */
    getSubaccountFeeRates(params: GetEngineSubaccountFeeRatesParams): Promise<import("@vertex-protocol/engine-client").GetEngineSubaccountFeeRatesResponse>;
    /**
     * Retrieves the current signer and link signer rate limit from the indexer
     * @param params
     */
    getSubaccountLinkedSignerWithRateLimit(params: GetIndexerLinkedSignerParams): Promise<import("@vertex-protocol/indexer-client").GetIndexerLinkedSignerResponse>;
    /**
     * Retrieves referral code for an address
     * @param params
     */
    getReferralCode(params: GetIndexerReferralCodeParams): Promise<import("@vertex-protocol/indexer-client").GetIndexerReferralCodeResponse>;
}
//# sourceMappingURL=SubaccountQueryAPI.d.ts.map