import { EngineExecuteRequestParamsByType, WithSignature } from '@vertex-protocol/engine-client';
import { BaseVertexAPI } from '../base';
import { EIP712OrderParams } from '@vertex-protocol/contracts';
/**
 * Builds execute messages as expected by the server to send over Websocket.
 * @example vertexClient.ws.execute.buildPlaceOrderMessage(...)
 */
export declare class WebSocketExecuteAPI extends BaseVertexAPI {
    /**
     * Builds ws message for the `liquidate_subaccount` execute action.
     * @param params LiquidateSubaccount params.
     * @returns `liquidate_subaccount` execute message
     */
    buildLiquidateSubaccountMessage(params: EngineExecuteRequestParamsByType['liquidate_subaccount']): Promise<import("@vertex-protocol/contracts").SignedTx<import("@vertex-protocol/contracts").EIP712LiquidateSubaccountValues>>;
    /**
     * Builds ws message for the `withdraw_collateral` execute action.
     * @param params WithdrawCollateral params.
     * @returns `liquidate_subaccount` execute message
     */
    buildWithdrawCollateralMessage(params: EngineExecuteRequestParamsByType['withdraw_collateral']): Promise<import("@vertex-protocol/contracts").SignedTx<import("@vertex-protocol/contracts").EIP712WithdrawCollateralValues> & {
        spot_leverage: boolean | null;
    }>;
    /**
     * Builds ws message for the `mint_lp` execute action.
     * @param params MintLp params.
     * @returns `mint_lp` execute message
     */
    buildMintLpMessage(params: EngineExecuteRequestParamsByType['mint_lp']): Promise<import("@vertex-protocol/contracts").SignedTx<import("@vertex-protocol/contracts").EIP712MintLpValues> & {
        spot_leverage: boolean | null;
    }>;
    /**
     * Builds ws message for the `burn_lp` execute action.
     * @param params BurnLp params.
     * @returns `burn_lp` execute message
     */
    buildBurnLpMessage(params: EngineExecuteRequestParamsByType['burn_lp']): Promise<import("@vertex-protocol/contracts").SignedTx<import("@vertex-protocol/contracts").EIP712BurnLpValues>>;
    /**
     * Builds ws message for the `place_order` execute action.
     * @param params PlaceOrder params.
     * @returns `place_order` execute message
     */
    buildPlaceOrderMessage(params: WithSignature<EngineExecuteRequestParamsByType['place_order'] & {
        order: EIP712OrderParams;
    }>): import("@vertex-protocol/engine-client").EngineServerExecutePlaceOrderPayload;
    /**
     * Builds ws message for the `cancel_orders` execute action.
     * @param params PlaceOrder params.
     * @returns `cancel_orders` execute message
     */
    buildCancelOrdersMessage(params: WithSignature<EngineExecuteRequestParamsByType['cancel_orders'] & {
        nonce: string;
    }>): import("@vertex-protocol/engine-client").EngineServerCancelOrdersParams;
}
//# sourceMappingURL=WebSocketExecuteAPI.d.ts.map