import { BaseVertexAPI } from '../base';
/**
 * Builds execute messages as expected by the server to send over Websocket.
 * @example vertexClient.ws.execute.buildPlaceOrderMessage(...)
 */
export class WebSocketExecuteAPI extends BaseVertexAPI {
    /**
     * Builds ws message for the `liquidate_subaccount` execute action.
     * @param params LiquidateSubaccount params.
     * @returns `liquidate_subaccount` execute message
     */
    async buildLiquidateSubaccountMessage(params) {
        return this.context.engineClient.payloadBuilder.buildLiquidateSubaccountPayload(params);
    }
    /**
     * Builds ws message for the `withdraw_collateral` execute action.
     * @param params WithdrawCollateral params.
     * @returns `liquidate_subaccount` execute message
     */
    async buildWithdrawCollateralMessage(params) {
        return this.context.engineClient.payloadBuilder.buildWithdrawCollateralPayload(params);
    }
    /**
     * Builds ws message for the `mint_lp` execute action.
     * @param params MintLp params.
     * @returns `mint_lp` execute message
     */
    async buildMintLpMessage(params) {
        return this.context.engineClient.payloadBuilder.buildMintLpPayload(params);
    }
    /**
     * Builds ws message for the `burn_lp` execute action.
     * @param params BurnLp params.
     * @returns `burn_lp` execute message
     */
    async buildBurnLpMessage(params) {
        return this.context.engineClient.payloadBuilder.buildBurnLpPayload(params);
    }
    /**
     * Builds ws message for the `place_order` execute action.
     * @param params PlaceOrder params.
     * @returns `place_order` execute message
     */
    buildPlaceOrderMessage(params) {
        return this.context.engineClient.payloadBuilder.buildPlaceOrderPayloadSync(params);
    }
    /**
     * Builds ws message for the `cancel_orders` execute action.
     * @param params PlaceOrder params.
     * @returns `cancel_orders` execute message
     */
    buildCancelOrdersMessage(params) {
        return this.context.engineClient.payloadBuilder.buildCancelOrdersPayloadSync(params);
    }
}
//# sourceMappingURL=WebSocketExecuteAPI.js.map