import { BaseVertexAPI } from '../base';
/**
 * Builds subscription messages as expected by the server to send over Websocket.
 *
 * @example
 * const tradeSubscriptionParams = vertexClient.ws.subscription.buildSubscriptionParams('trade', ...);
 * const tradeSubscriptionMessage = vertexClient.ws.subscription.buildSubscriptionMessage(
 *    'subscribe', tradeSubscriptionParams);
 */
export class WebSocketSubscriptionAPI extends BaseVertexAPI {
    /**
     * Builds a subscription request message as expected by the server via Websocket.
     * @param requestType name of request to build message for.
     * @param id identifier to associate messages with responses.
     * @param params request message params.
     * @returns subscription request message.
     */
    buildSubscriptionMessage(id, requestType, params) {
        return {
            id,
            method: requestType,
            ...params,
        };
    }
    /**
     * Builds a subscription stream param as expected by the server via Websocket.
     * @param streamType name of stream to build params for.
     * @param params
     * @returns subscription stream params.
     */
    buildSubscriptionParams(streamType, params) {
        return {
            stream: {
                type: streamType,
                ...params,
            },
        };
    }
}
//# sourceMappingURL=WebSocketSubscriptionAPI.js.map