import { VERTEX_ABIS, VERTEX_DEPLOYMENTS, } from '@vertex-protocol/contracts';
import { ENGINE_CLIENT_ENDPOINTS, EngineClient, } from '@vertex-protocol/engine-client';
import { INDEXER_CLIENT_ENDPOINTS, IndexerClient, } from '@vertex-protocol/indexer-client';
import { TRIGGER_CLIENT_ENDPOINTS, TriggerClient, } from '@vertex-protocol/trigger-client';
import { getContract } from 'viem';
/**
 * Utility function to create client context from options
 *
 * @param opts
 * @param accountOpts
 */
export function createClientContext(opts, accountOpts) {
    const { contractAddresses, engineEndpoint, indexerEndpoint, triggerEndpoint, } = (() => {
        // Custom options
        if (typeof opts === 'object') {
            return opts;
        }
        const chainEnv = opts;
        return {
            contractAddresses: VERTEX_DEPLOYMENTS[chainEnv],
            engineEndpoint: ENGINE_CLIENT_ENDPOINTS[chainEnv],
            indexerEndpoint: INDEXER_CLIENT_ENDPOINTS[chainEnv],
            triggerEndpoint: TRIGGER_CLIENT_ENDPOINTS[chainEnv],
        };
    })();
    const { publicClient, walletClient, linkedSignerWalletClient } = accountOpts;
    return {
        walletClient,
        linkedSignerWalletClient,
        publicClient,
        contracts: {
            querier: getVertexContract({
                contractAddresses,
                contractName: 'querier',
                walletClient,
                publicClient,
            }),
            clearinghouse: getVertexContract({
                contractAddresses,
                contractName: 'clearinghouse',
                walletClient,
                publicClient,
            }),
            endpoint: getVertexContract({
                contractAddresses,
                contractName: 'endpoint',
                walletClient,
                publicClient,
            }),
            spotEngine: getVertexContract({
                contractAddresses,
                contractName: 'spotEngine',
                walletClient,
                publicClient,
            }),
            perpEngine: getVertexContract({
                contractAddresses,
                contractName: 'perpEngine',
                walletClient,
                publicClient,
            }),
            foundationRewardsAirdrop: getVertexContract({
                contractAddresses,
                contractName: 'foundationRewardsAirdrop',
                walletClient,
                publicClient,
            }),
            withdrawPool: getVertexContract({
                contractAddresses,
                contractName: 'withdrawPool',
                walletClient,
                publicClient,
            }),
            vrtxToken: getVertexContract({
                contractAddresses,
                contractName: 'vrtxToken',
                walletClient,
                publicClient,
            }),
            vrtxAirdrop: getVertexContract({
                contractAddresses,
                contractName: 'vrtxAirdrop',
                walletClient,
                publicClient,
            }),
            vrtxLba: getVertexContract({
                contractAddresses,
                contractName: 'vrtxLba',
                walletClient,
                publicClient,
            }),
            vrtxVesting: getVertexContract({
                contractAddresses,
                contractName: 'vrtxVesting',
                walletClient,
                publicClient,
            }),
            vrtxStaking: getVertexContract({
                contractAddresses,
                contractName: 'vrtxStaking',
                walletClient,
                publicClient,
            }),
            vrtxStakingV2: getVertexContract({
                contractAddresses,
                contractName: 'vrtxStakingV2',
                walletClient,
                publicClient,
            }),
            vrtxStakingV2Satellite: getVertexContract({
                contractAddresses,
                contractName: 'vrtxStakingV2Satellite',
                walletClient,
                publicClient,
            }),
        },
        contractAddresses,
        engineClient: new EngineClient({
            url: engineEndpoint,
            walletClient,
            linkedSignerWalletClient,
        }),
        indexerClient: new IndexerClient({
            url: indexerEndpoint,
            walletClient,
        }),
        triggerClient: new TriggerClient({
            url: triggerEndpoint,
            walletClient,
            linkedSignerWalletClient,
        }),
    };
}
function getVertexContract({ contractAddresses, contractName, walletClient, publicClient, }) {
    return getContract({
        address: contractAddresses[contractName],
        abi: VERTEX_ABIS[contractName],
        client: walletClient ?? publicClient,
    });
}
//# sourceMappingURL=context.js.map